@@ -9,6 +9,6 @@
 #define POST 0
 #define GET 1
 
-SEXP ROAuth_HTTP(SEXP, SEXP, SEXP, SEXP, SEXP, int);
-SEXP ROAuth_POST(SEXP, SEXP, SEXP, SEXP, SEXP);
-SEXP ROAuth_GET(SEXP, SEXP, SEXP, SEXP, SEXP);
+SEXP ROAuth_HTTP(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, int);
+SEXP ROAuth_POST(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+SEXP ROAuth_GET(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
